@@ -4,6 +4,7 @@ import requests
 from stoobly_agent.app.api.simple_http_request_handler import SimpleHTTPRequestHandler
 from stoobly_agent.app.models.response_model import ResponseModel
 from stoobly_agent.app.settings import Settings
+from stoobly_agent.config.constants import custom_headers
 
 class ResponsesController:
     _instance = None
@@ -21,7 +22,7 @@ class ResponsesController:
 
         return cls._instance
 
-    # GET /requests/:requestId/bodies/mock
+    # GET /requests/:requestId/responses/mock
     def mock(self, context: SimpleHTTPRequestHandler):
         context.parse_path_params({
             'requestId': 1
@@ -30,6 +31,14 @@ class ResponsesController:
         response_model = self.__response_model(context) 
         response: requests.Response = response_model.mock(context.params.get('requestId'))
 
+        return self.__render_response(context, response)
+
+    def __response_model(self, context: SimpleHTTPRequestHandler):
+        response_model = ResponseModel(Settings.instance())
+        response_model.as_remote() if context.headers.get('access-token') else response_model.as_local()
+        return response_model
+
+    def __render_response(self, context: SimpleHTTPRequestHandler, response: requests.Response):
         if response == None:
             return context.render(
                 plain = '',
@@ -37,9 +46,11 @@ class ResponsesController:
             )
 
         # Extract specific headers
-        headers = {}
+        headers = {
+            'Access-Control-Expose-Headers': custom_headers.RESPONSE_ID,
+        }
 
-        accepted_headers = ['content-type']
+        accepted_headers = ['content-type', custom_headers.RESPONSE_ID.lower()]
         for header, val in response.headers.items():
             decoded_header = header.lower()
 
@@ -52,9 +63,4 @@ class ResponsesController:
             data = response.content,
             headers = headers,
             status = 200
-        )
-
-    def __response_model(self, context: SimpleHTTPRequestHandler):
-        response_model = ResponseModel(Settings.instance())
-        response_model.as_remote() if context.headers.get('access-token') else response_model.as_local()
-        return response_model
\ No newline at end of file
+        )
\ No newline at end of file
