@@ -58,6 +58,7 @@ def create(**kwargs):
 @click.option('--assign', multiple=True, help='Assign alias values. Format: <NAME>=<VALUE>')
 @click.option('--format', default=DEFAULT_FORMAT, type=click.Choice([DEFAULT_FORMAT, JSON_FORMAT]), help='Format replay response.')
 @click.option('--group-by', help='Repeat for each alias name.')
+@click.option('--host', help='Rewrite request host.')
 @click.option('--lifecycle-hooks-script-path', help='Path to lifecycle hooks script.')
 @click.option(
     '--log-level', default=logger.WARNING, type=click.Choice([logger.DEBUG, logger.INFO, logger.WARNING, logger.ERROR]), 
@@ -67,7 +68,9 @@ def create(**kwargs):
 )
 @click.option('--record', is_flag=True, default=False, help='Replay and record scenario.')
 @click.option('--scenario-key', help='Record to scenario.')
+@click.option('--scheme', help='Rewrite request scheme.')
 @click.option('--trace-id', help='Use existing trace.')
+@click.option('--validate', multiple=True, help='Validate one or more aliases. Format: <NAME>=?<TYPE>')
 @click.argument('key')
 def replay(**kwargs):
     os.environ[env_vars.LOG_LEVEL] = kwargs['log_level']
@@ -81,6 +84,9 @@ def replay(**kwargs):
 
         validate_scenario_key(kwargs['scenario_key'])
 
+    if len(kwargs['validate']):
+        validate_aliases(kwargs['validate'], assign=kwargs['assign'], format=kwargs['format'], trace_id=kwargs['trace_id'])
+
     __assign_default_alias_resolve_strategy(kwargs)
 
     kwargs['before_replay'] = lambda context: handle_before_replay(
@@ -112,6 +118,7 @@ def replay(**kwargs):
 )
 @click.option('--format', default=DEFAULT_FORMAT, type=click.Choice([DEFAULT_FORMAT, JSON_FORMAT]), help='Format replay response.')
 @click.option('--group-by', help='Repeat for each alias name.')
+@click.option('--host', help='Rewrite request host.')
 @click.option('--lifecycle-hooks-script-path', help='Path to lifecycle hooks script.')
 @click.option(
     '--log-level', default=logger.WARNING, type=click.Choice([logger.DEBUG, logger.INFO, logger.WARNING, logger.ERROR]), 
@@ -120,6 +127,7 @@ def replay(**kwargs):
     '''
 )
 @click.option('--report-key', help='Save to report.')
+@click.option('--scheme', help='Rewrite request scheme.')
 @click.option(
     '--strategy', 
     default=test_strategy.DIFF, 
@@ -127,6 +135,7 @@ def replay(**kwargs):
     help='How to test responses.'
 )
 @click.option('--trace-id', help='Use existing trace.')
+@click.option('--validate', multiple=True, help='Validate one or more aliases. Format: <NAME>=?<TYPE>')
 @click.argument('key')
 def test(**kwargs):
     os.environ[env_vars.LOG_LEVEL] = kwargs['log_level']
@@ -138,6 +147,9 @@ def test(**kwargs):
     if kwargs.get('report_key'):
         validate_report_key(kwargs['report_key'])
 
+    if len(kwargs['validate']):
+        validate_aliases(kwargs['validate'], assign=kwargs['assign'], format=kwargs['format'], trace_id=kwargs['trace_id'])
+
     __assign_default_alias_resolve_strategy(kwargs)
 
     session_context: SessionContext = { 
@@ -158,9 +170,9 @@ def test(**kwargs):
     scenario = ScenarioFacade(settings)
     scenario.test(kwargs['key'], kwargs)
 
-    handle_test_session_complete(session_context)
+    handle_test_session_complete(session_context, kwargs['format'])
 
-    exit_on_failure(session_context)
+    exit_on_failure(session_context, format=kwargs['format'])
 
 @scenario.command(
     help="Show all scenarios"
@@ -215,7 +227,7 @@ def __handle_on_test_response(replay_context: ReplayContext, session_context: Se
     handle_test_complete(replay_context, session_context, format)
 
     if not session_context['aggregate_failures']:
-        exit_on_failure(session_context, False)
+        exit_on_failure(session_context, complete=False, format=format)
 
 def __assign_default_alias_resolve_strategy(kwargs):
     # If we have assigned values to aliases, it's likely we want to also have them resolved
